* *******************************************************************
* Does aid harm PR?: Evidence from US aid replication file		 	*
* Created : December 2011											*
* Edited: March 2016												*
* Coder: Faisal Ahmed												*
*****************************************************************

* Clear data from memory
drop _all

* Set memory
set maxvar 5000
set matsize 5000
mata: mata set matafavor speed, perm

* Open log file
set logtype text
log using aidrepression_regressions_qjps.log, replace


use usaid_qjps.dta

set more off

* Generate country and year fixed effects
tab cname, gen(codummy)
tab year, gen(ydummy)


**********************************************************
* RESULTS FOR PAPER, 3.2016
**********************************************************
* FIGURES
* Figure 2: FRAG and average aid
label var hfrag "Fragmentation in House of Rep."
graph twoway (lfit yavg_lnraidus_cpi hfrag) (scatter yavg_lnraidus_cpi hfrag, mlabel(year)) if cname=="Jordan", ytitle(Average log US bilateral econ. aid (2000 US$)) legend(off)

* Figure 3: Paidus and average aid
graph twoway (lfit cavg_lnraidus_cpi paidus) (scatter cavg_lnraidus_cpi paidus, mlabel(cname_s))  if year==2009, ytitle(Log US bilateral aid (2000 US$)) legend(off)

* Figure 4: Less annual variability in aid levels for more frequent aid recipients
graph twoway (lfit lnraidus_sd paidus) (scatter lnraidus_sd paidus, mlabel(cname_s))  if year==2009, ytitle(Standard deviation in log US bilateral aid (2000 US$)) legend(off)


* SUMMARY STATISTICS
areg polright lnraidus lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy*, absorb(cname) cluster(cname)
gen olssamp=e(sample)

* Table: Summary Statistics
sum polright lnraidus lnrtotaidus lnrmaidus inst hfrag paidus lngdpcap ggdpcap lnpop unsc usally lnrusexp if olssamp==1


*****************
* REGRESSIONS
*******************
* TABLE 1: FIRST STAGE REGRESSION
reg lnraidus inst paidus hfrag lngdpcap ggdpcap lnpop unsc usally lnrusexp if polright!=., cluster(cname)
test inst

* FIGURE 5
label var hfrag "Fragmentation in House of Rep."
grinter hfrag, inter(inst) const02(paidus) nomean clevel(90)

areg lnraidus inst lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if polright!=., absorb(cname) cluster(cname)
test inst

areg lnrtotaidus inst lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if polright!=. & lnraidus!=., absorb(cname) cluster(cname)
test inst

areg lnrmaidus inst lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if polright!=. & lnraidus!=., absorb(cname) cluster(cname)
test inst

***
* TABLE 2: AID HARMS POLITICAL RIGHTS
* (1): OLS (with fixed effects)
areg polright lnraidus lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy*, absorb(cname) cluster(cname)

* (2): IV (no fixed effects)
ivreg polright (lnraidus=inst) hfrag paidus lngdpcap ggdpcap lnpop unsc usally lnrusexp, cluster(cname)
* for r-squared
* reg polright lnraidus hfrag paidus lngdpcap ggdpcap lnpop unsc usally lnrusexp, cluster(cname)

* (3): IV with fixed effects
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)

* (4-5): US economic and military aid
ivreg polright (lnrtotaidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* if lnraidus!=., cluster(cname)

* Instrument for military aid
ivreg polright (lnrmaidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* if lnraidus!=., cluster(cname)

* (6) Control for military aid separately
ivreg polright (lnraidus=inst) lnrmaidus  lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
areg lnraidus inst lnrmaidus  lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy*, absorb(cname) cluster(cname)
test inst

* (7) No time-varying controls
ivreg polright (lnraidus=inst) ydummy* codummy*, cluster(cname)
areg lnraidus inst ydummy* if polright!=., absorb(cname) cluster(cname)
test inst

* (8) Lagged aid
ivreg polright (lag_lnraidus=lag_inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
areg lag_lnraidus lag_inst lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if polright!=., absorb(cname) cluster(cname)
test lag_inst

* (9) Lagged aid (2 years)
ivreg polright (lag2_lnraidus=lag2_inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
areg lag2_lnraidus lag2_inst lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if polright!=., absorb(cname) cluster(cname)
test lag2_inst

* (10) Lagged aid (5 years)
ivreg polright (lag5_lnraidus=lag5_inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
areg lag5_lnraidus lag5_inst lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if polright!=., absorb(cname) cluster(cname)
test lag5_inst

*****
* TABLE 3: EXTENDED RESULTS
* Panel A
* YEAR TREND (with year and country fixed effects)
ivreg polright (lnraidus=inst) year lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
areg lnraidus inst year lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if polright!=., absorb(cname) cluster(cname)
test inst

* TEMPORAL OUTLIERS: POST COLD WAR, PRE-2001
* Post CW sample
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* if coldwar==0, cluster(cname)
areg lnraidus inst lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if coldwar==0 & polright!=., absorb(cname) cluster(cname)
test inst

* Pre-2001
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* if year<=2000, cluster(cname)
areg lnraidus inst lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if year<=2000 & polright!=., absorb(cname) cluster(cname)
test inst

* AID OUTLIERS
* Outliers: Exclude top decile of aid recipients, by level of aid
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* if lnraidus<18.26576, cluster(cname)
areg lnraidus inst lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if lnraidus<18.26576 & polright!=., absorb(cname) cluster(cname)
test inst

* Outliers: Exclude countries that receive aid a lot, say paidus>0.90
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* if paidus<0.90, cluster(cname)
areg lnraidus inst lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if paidus<0.90 & polright!=., absorb(cname) cluster(cname)
test inst

* Outliers: Exclude countries that do NOT receive aid a lot, say paidux<0.10
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* if paidus>0.10, cluster(cname)
areg lnraidus inst lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if paidus>0.10 & polright!=., absorb(cname) cluster(cname)
test inst


* Panel B: Alternate dependent variables
ivreg civlib (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
areg lnraidus inst lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if civlib!=., absorb(cname) cluster(cname)
test inst

* higher values of parcomp_new mean an increase in repression
ivreg parcomp_new (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
areg lnraidus inst lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if parcomp_new!=., absorb(cname) cluster(cname)
test inst

* Religious freedom (3 point index from CIRI)
* rep_relfre = higher values imply a reduction in religous freedom
ivreg rep_relfre (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
areg lnraidus inst lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if rep_relfre!=., absorb(cname) cluster(cname)
test inst

* Empowerment index: 15 point - 0 (no government respect for seven rights), 14 (full government respect). 
ivreg rep_empinx (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
areg lnraidus inst lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if rep_empinx!=., absorb(cname) cluster(cname)
test inst

* Political imprisonment (3 point index from CIRI)
* Higher values of rep_polpris imply greater repression
ivreg rep_polpris (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
areg lnraidus inst lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if rep_polpris!=., absorb(cname) cluster(cname)
test inst



*****
* TABLE 4: EVALUATING THE EXCLUSION RESTRICTION
* Z(i): hfrag_oilproducer hfrag_colony hfrag_usally hfrag_yrindep
* Z(t): paidus_poil paidus_unsc paidus_prespartydum
* Alternate instruments: inst_can inst_uk

* NOTE: First regression corresponds to panel A, Second regression correponds to panel B

* (1): FRAG x Z(i)
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp hfrag_oilproducer hfrag_colony hfrag_usally hfrag_yrindep ydummy* codummy*, cluster(cname)
areg lnraidus inst lngdpcap ggdpcap lnpop unsc usally lnrusexp hfrag_oilproducer hfrag_colony hfrag_usally hfrag_yrindep ydummy* if polright!=., absorb(cname) cluster(cname)
test inst

* (2): P(i) x Z(t)
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp paidus_poil paidus_unsc paidus_prespartydum ydummy* codummy*, cluster(cname)
areg lnraidus inst lngdpcap ggdpcap lnpop unsc usally lnrusexp paidus_poil paidus_unsc paidus_prespartydum ydummy* if polright!=., cluster(cname) absorb(cname)
test inst

* (3): P(i)x Z(t), FRAG x Z(i)
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp paidus_poil paidus_unsc paidus_prespartydum hfrag_oilproducer hfrag_colony hfrag_usally hfrag_yrindep ydummy*  codummy*, cluster(cname)
areg lnraidus inst lngdpcap ggdpcap lnpop unsc usally lnrusexp paidus_poil paidus_unsc paidus_prespartydum hfrag_oilproducer hfrag_colony hfrag_usally hfrag_yrindep ydummy* if polright!=., absorb(cname) cluster(cname)
test inst

* USE INSTRUMENT USING Prob. of receiving aid from Canada and UK
* (4): CANADA
ivreg polright (lnraidus=inst_can) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
areg lnraidus inst_can lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if polright!=., absorb(cname) cluster(cname)
test inst_can

* (5): UK
ivreg polright (lnraidus=inst_uk) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
areg lnraidus inst_uk lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if polright!=., absorb(cname) cluster(cname)
test inst_uk

*************
* TABLE 5: EVALUATING MECHANISMS
* Panel A: Rent-seeking
* Anti-government demonstrations
ivreg demonstration (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)

* Assassinations: ACROSS ALL COUNTRIES, AUTOCRACIES, AND DEMOCRACIES
ivreg assassin (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
ivreg assassin (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* if cavg_polity2<0, cluster(cname)
ivreg assassin (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* if cavg_polity2>=0, cluster(cname)

* Composition of government spending
ivreg transfers (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
ivreg military_expenditure (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)


***
* Panel B: Military spending, by regime type
* Log military expenditures
ivreg lnrmilexp (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
ivreg lnrmilexp (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* if cavg_polity<0, cluster(cname)
ivreg lnrmilexp (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* if cavg_polity>=0, cluster(cname)

* Log military personnel
ivreg lnmilpersonnel (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
ivreg lnmilpersonnel (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* if cavg_polity2<0, cluster(cname)
ivreg lnmilpersonnel (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* if cavg_polity2>=0, cluster(cname)

****
* Panel C: Taxation
areg incometaxrev lngdpcap lnpop ggdpcap polright unsc usally lnrusexp  ydummy* if polright!=., absorb(cname) cluster(cname)
areg incometaxrev lnraidus lngdpcap lnpop ggdpcap unsc usally lnrusexp ydummy*, cluster(cname) absorb(cname)
ivreg incometaxrev (lnraidus=inst) lngdpcap lnpop ggdpcap unsc usally lnrusexp ydummy* codummy*, cluster(cname)
ivreg incometaxrev (lnraidus=inst) polright lngdpcap lnpop ggdpcap unsc usally lnrusexp ydummy* codummy*, cluster(cname)



***********************
* APPENDIX TABLES
************************
* TABLE B1: ALTERNATE SPECIFICATIONS
* Columns 1-3: Constituent terms of the instrumental variable
ivreg polright (lnraidus=inst) paidus lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy*, cluster(cname)
reg lnraidus inst paidus lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if polright!=., cluster(cname)
test inst

ivreg polright (lnraidus=inst) hfrag lngdpcap ggdpcap lnpop unsc usally lnrusexp codummy*, cluster(cname)
areg lnraidus inst hfrag lngdpcap ggdpcap lnpop unsc usally lnrusexp if polright!=., absorb(cname) cluster(cname)
test inst

ivreg polright (lnraidus=inst) paidus hfrag lngdpcap ggdpcap lnpop unsc usally lnrusexp, cluster(cname)
reg lnraidus inst hfrag paidus lngdpcap ggdpcap lnpop unsc usally lnrusexp if polright!=., cluster(cname)
test inst

* LAGS AND LEADS
ivreg polright (lnraidus=inst) lag_lnraidus lngdpcap ggdpcap lnpop unsc usally lnrusexp codummy* ydummy*, cluster(cname)
ivreg polright (lnraidus=inst) lag_lnraidus lead_lnraidus lngdpcap ggdpcap lnpop unsc usally lnrusexp codummy* ydummy*, cluster(cname)

* Alternate specifications: 2 and 5 year average data
ivreg polright_2yr (lnraidus_2yr=inst_2yr) lngdpcap_2yr ggdpcap_2yr lnpop_2yr unsc_2yr usally_2yr lnrusexp_2yr ydummy* codummy* if year>=1972 & avgyr2==1,  cluster(cname)
ivreg polright_5yr (lnraidus_5yr=inst_5yr) lngdpcap_5yr ggdpcap_5yr lnpop_5yr unsc_5yr usally_5yr lnrusexp_5yr ydummy* codummy* if year>=1972 & avgyr5==1,  cluster(cname)

* ALTERNATE CLUSTERING
ivreg2 polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp codummy* ydummy*, cluster(cname year)
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp codummy* ydummy*, cluster(regionyr)
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp codummy* ydummy*, cluster(year)

***
* TABLE B2: ADDITIONAL CONTROLS
* Additional recipient characteristics
ivreg polright (lnraidus=inst) xconst lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
ivreg polright (lnraidus=inst) durable lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
ivreg polright (lnraidus=inst) lnrfuelexp lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
ivreg polright (lnraidus=inst) lnarmimport lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
ivreg polright (lnraidus=inst) cwar lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
ivreg polright (lnraidus=inst) tradeopen lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)

* Account for "foreign born" channel
ivreg polright (lnraidus=inst) pctforborn lngdpcap ggdpcap lnpop unsc usally lnrusexp hfrag codummy*, cluster(cname)
ivreg polright (lnraidus=inst) pctforborn_R pctforborn_D lngdpcap ggdpcap lnpop unsc usally lnrusexp hfrag codummy*, cluster(cname)

***
* TABLE B3: INSTRUMENT WITH SENATE FRAGMENTATION
ivreg polright (lnraidus=inst_sen) sfrag paidus lngdpcap ggdpcap lnpop unsc usally lnrusexp, cluster(cname)
reg lnraidus inst_sen sfrag paidus lngdpcap ggdpcap lnpop unsc usally lnrusexp if polright!=., cluster(cname)
test inst_sen

ivreg polright (lnraidus=inst_sen) paidus lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy*, cluster(cname)
reg lnraidus inst_sen paidus lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if polright!=., cluster(cname)
test inst_sen

ivreg polright (lnraidus=inst_sen) sfrag lngdpcap ggdpcap lnpop unsc usally lnrusexp codummy*, cluster(cname)
areg lnraidus inst_sen sfrag lngdpcap ggdpcap lnpop unsc usally lnrusexp if polright!=., absorb(cname) cluster(cname)
test inst_sen

ivreg polright (lnraidus=inst_sen) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
areg lnraidus inst_sen lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if polright!=., absorb(cname) cluster(cname)
test inst_sen

***
* TABLE B4: ALTERNATE MEASURES OF TIME-VARYING P(i)
* Time-varying measure of Pi
ivreg polright (lnraidus=inst_tv) ptimevary lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
areg lnraidus inst_tv ptimevary lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy*  if polright!=., absorb(cname) cluster(cname)
test inst_tv

* Instrument: FRAG x Recieved aid in year t-1
ivreg polright (lnraidus=inst_rec1) usaidrec1 lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
areg lnraidus inst_rec1 usaidrec1 lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if polright!=., absorb(cname) cluster(cname)
test inst_rec1

* Instrument: FRAG x Recieved aid in year t-2
ivreg polright (lnraidus=inst_rec2) usaidrec2 lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
areg lnraidus inst_rec2 usaidrec2 lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if polright!=., absorb(cname) cluster(cname)
test inst_rec2

* Instrument: FRAG x Recieved aid in year t-5
ivreg polright (lnraidus=inst_rec5) usaidrec5 lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
areg lnraidus inst_rec5 usaidrec5 lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if polright!=., absorb(cname) cluster(cname)
test inst_rec5

***
* TABLE B5: ALTERNATE SAMPLES
* Outliers: Exclude top decile of aid recipients, by level of aid
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* if lnraidus<18.26576, cluster(cname)

* Outliers: Exclude countries that receive aid a lot, say paidus>0.90
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* if paidus<0.90, cluster(cname)

* Exclude countries with low populations (excl. if pop<2M, 5M)
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* if ctry_pop>2000000, cluster(cname)
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* if ctry_pop>5000000, cluster(cname)

****
* TABLE B6: CROWDING OUT
areg lnrnonaidus lnraidus lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* if polright!=., absorb(cname) cluster(cname)
ivreg lnrnonaidus (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* if polright!=., cluster(cname)

***
* TABLE B7: ACCOUNTING FOR TEMPORAL FACTORS
* (1) Control for ColdWar and 9/11 epochs
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp coldwar post911 codummy* ydummy*, cluster(cname)

* (2) Control for Region FE x Cold War dummy
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp asia africa meast nam sam europe coldwar asiacw africacw meastcw namcw samcw europecw  ydummy* codummy*, cluster(cname)
lincom _b[asia]+_b[asiacw]
lincom _b[africa]+_b[africacw]
lincom _b[meast]+_b[meastcw]
lincom _b[nam]+_b[namcw]
lincom _b[sam]+_b[samcw]
lincom _b[europe]+_b[europecw]

* (3) Control for Country FE x Cold War dummy
foreach x of numlist 1/198 {
gen ctrycw`x'=coldwar*codummy`x'
}
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ctrycw* coldwar codummy* ydummy*, cluster(cname)

* (4) Post CW sample with region FE
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp asia africa meast nam sam europe ydummy* codummy* if coldwar==0, cluster(cname)

***
* TABLE B8: ACCOUNTING FOR SPATIAL HETEROGENEITY AND COUNTRY-SPECIFIC FACTORS
* Control for regional diffusion
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* polity2_region cwar_region ggdpcap_region trade_region, cluster(cname)

* Control for annual change in POLITY
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp dpolity2 ydummy* codummy*, cluster(cname)

* Control for region FE x US ally
ivreg polright (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp asia_ally africa_ally meast_ally nam_ally sam_ally europe_ally asia africa meast nam sam europe ydummy* codummy*, cluster(cname)


****
* TABLE D1: AID AND AUTHORITARIAN STABILITY
ivreg xconst (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
ivreg polity2 (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
ivreg durable (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy*, cluster(cname)
ivreg durable (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* if cavg_polity2<0, cluster(cname)
ivreg durable (lnraidus=inst) lngdpcap ggdpcap lnpop unsc usally lnrusexp ydummy* codummy* if cavg_polity2>=0, cluster(cname)












